Hasil Pencarian - AHU Online

### Hasil Pencarian Perseroan: Contoh

Nama Perusahaan | Nomor Pengesahan | Bentuk Badan Usaha | Domisili | Status Perusahaan
--- | --- | --- | --- | ---
PT CONTOH INDONESIA TBK | AHU-0012345.AH.01.01.TAHUN2020 | Perseroan Terbatas (PT) | Jakarta Pusat | AKTIF
PT CONTOH MAJU BERSAMA | AHU-0067890.AH.01.01.TAHUN2019 | Perseroan Terbatas (PT) | Surabaya | AKTIF
CV CONTOH USAHA MANDIRI | AHU-0054321.AH.02.01.TAHUN2018 | Comanditaire Vennootschap (CV) | Bandung | AKTIF